==> risk-center-api-0.2.0-20180627.023308-15-sources.jar: cn/com/duiba/tuia/risk/center/api/dto/AdvertInspectDto.java <==
package cn.com.duiba.tuia.risk.center.api.dto;

import java.io.Serializable;
import java.util.Date;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

@ApiModel
public class AdvertInspectDto implements Serializable {
	@ApiModelProperty("广告id")
	private Long    advertId;
	@ApiModelProperty("广告名称")
	private String  advertName;
	@ApiModelProperty("广告主名称")
	private String  advertMaster;
	@ApiModelProperty("代理商名称")
	private String  agentName;
	@ApiModelProperty("来源")
	private Integer source;
	@ApiModelProperty("巡检状态 0 待巡检   1，2，3 已巡检")
	private Integer inspectStatus;
	@ApiModelProperty("最近巡检结果")
	private Integer  inspectResult;
	@ApiModelProperty("巡检累计次数")
	private Integer inspectCount;
	@ApiModelProperty("巡检备注")
	private String  inspectMemo;
	@ApiModelProperty("最近巡检时间")
	private Date inspectTime;
	@ApiModelProperty("初审")
	private String firstReviewer;
	@ApiModelProperty("ae")
	private String ae;
	@ApiModelProperty("销售")
	private String sale;
	@ApiModelProperty("复审")
	private String secondReviewer;
	@ApiModelProperty("最近审核时间")
	private Date   lastReviewTime;

	public Long getAdvertId() {
		return advertId;
	}

	public void setAdvertId(Long advertId) {
		this.advertId = advertId;
	}

	public String getAdvertName() {
		return advertName;
	}

	public void setAdvertName(String advertName) {
		this.advertName = advertName;
	}

	public String getAdvertMaster() {
		return advertMaster;
	}

	public void setAdvertMaster(String advertMaster) {
		this.advertMaster = advertMaster;
	}

	public String getAgentName() {
		return agentName;
	}

	public void setAgentName(String agentName) {
		this.agentName = agentName;
	}

	public Integer getSource() {
		return source;
	}

	public void setSource(Integer source) {
		this.source = source;
	}

	public Integer getInspectStatus() {
		return inspectStatus;
	}

	public void setInspectStatus(Integer inspectStatus) {
		this.inspectStatus = inspectStatus;
	}

	public Integer getInspectResult() {
		return inspectResult;
	}

	public void setInspectResult(Integer inspectResult) {
		this.inspectResult = inspectResult;
	}

	public Integer getInspectCount() {
		return inspectCount;
	}

	public void setInspectCount(Integer inspectCount) {
		this.inspectCount = inspectCount;
	}

	public String getInspectMemo() {
		return inspectMemo;
	}

	public void setInspectMemo(String inspectMemo) {
		this.inspectMemo = inspectMemo;
	}

	public Date getInspectTime() {
		return inspectTime;
	}

	public void setInspectTime(Date inspectTime) {
		this.inspectTime = inspectTime;
	}

	public String getFirstReviewer() {
		return firstReviewer;
	}

	public void setFirstReviewer(String firstReviewer) {
		this.firstReviewer = firstReviewer;
	}

	public String getAe() {
		return ae;
	}

	public void setAe(String ae) {
		this.ae = ae;
	}

	public String getSale() {
		return sale;
	}

	public void setSale(String sale) {
		this.sale = sale;
	}

	public String getSecondReviewer() {
		return secondReviewer;
	}

	public void setSecondReviewer(String secondReviewer) {
		this.secondReviewer = secondReviewer;
	}

	public Date getLastReviewTime() {
		return lastReviewTime;
	}

	public void setLastReviewTime(Date lastReviewTime) {
		this.lastReviewTime = lastReviewTime;
	}
}

==> risk-center-api-0.4.4-20180907.061608-2-sources.jar: cn/com/duiba/tuia/risk/center/api/dto/AdvertInspectDto.java <==
package cn.com.duiba.tuia.risk.center.api.dto;

import java.io.Serializable;
import java.util.Date;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

@ApiModel
public class AdvertInspectDto implements Serializable {
	@ApiModelProperty("广告id")
	private Long    advertId;
	@ApiModelProperty("广告名称")
	private String  advertName;
	@ApiModelProperty("广告主名称")
	private String  advertMaster;
	@ApiModelProperty("代理商名称")
	private String  agentName;
	@ApiModelProperty("广告状态:1-失效 0-未失效")
	private Integer  advertStatus;
	@ApiModelProperty("广告状态页面显示:1-失效 0-未失效")
	private String  advertStatusShow;
	@ApiModelProperty("来源")
	private Integer source;
	@ApiModelProperty("巡检状态 0 待巡检   1，2，3 已巡检")
	private Integer inspectStatus;
	@ApiModelProperty("最近巡检结果")
	private Integer  inspectResult;
	@ApiModelProperty("巡检累计次数")
	private Integer inspectCount;
	@ApiModelProperty("巡检备注")
	private String  inspectMemo;
	@ApiModelProperty("最近巡检时间")
	private Date inspectTime;
	@ApiModelProperty("初审")
	private String firstReviewer;
	@ApiModelProperty("ae")
	private String ae;
	@ApiModelProperty("销售")
	private String sale;
	@ApiModelProperty("复审")
	private String secondReviewer;
	@ApiModelProperty("最近审核时间")
	private Date   lastReviewTime;

	public Long getAdvertId() {
		return advertId;
	}

	public void setAdvertId(Long advertId) {
		this.advertId = advertId;
	}

	public String getAdvertName() {
		return advertName;
	}

	public void setAdvertName(String advertName) {
		this.advertName = advertName;
	}

	public String getAdvertMaster() {
		return advertMaster;
	}

	public void setAdvertMaster(String advertMaster) {
		this.advertMaster = advertMaster;
	}

	public String getAgentName() {
		return agentName;
	}

	public void setAgentName(String agentName) {
		this.agentName = agentName;
	}

	public Integer getSource() {
		return source;
	}

	public void setSource(Integer source) {
		this.source = source;
	}

	public Integer getInspectStatus() {
		return inspectStatus;
	}

	public void setInspectStatus(Integer inspectStatus) {
		this.inspectStatus = inspectStatus;
	}

	public Integer getInspectResult() {
		return inspectResult;
	}

	public void setInspectResult(Integer inspectResult) {
		this.inspectResult = inspectResult;
	}

	public Integer getInspectCount() {
		return inspectCount;
	}

	public void setInspectCount(Integer inspectCount) {
		this.inspectCount = inspectCount;
	}

	public String getInspectMemo() {
		return inspectMemo;
	}

	public void setInspectMemo(String inspectMemo) {
		this.inspectMemo = inspectMemo;
	}

	public Date getInspectTime() {
		return inspectTime;
	}

	public void setInspectTime(Date inspectTime) {
		this.inspectTime = inspectTime;
	}

	public String getFirstReviewer() {
		return firstReviewer;
	}

	public void setFirstReviewer(String firstReviewer) {
		this.firstReviewer = firstReviewer;
	}

	public String getAe() {
		return ae;
	}

	public void setAe(String ae) {
		this.ae = ae;
	}

	public String getSale() {
		return sale;
	}

	public void setSale(String sale) {
		this.sale = sale;
	}

	public String getSecondReviewer() {
		return secondReviewer;
	}

	public void setSecondReviewer(String secondReviewer) {
		this.secondReviewer = secondReviewer;
	}

	public Date getLastReviewTime() {
		return lastReviewTime;
	}

	public void setLastReviewTime(Date lastReviewTime) {
		this.lastReviewTime = lastReviewTime;
	}

	public Integer getAdvertStatus() {
		return advertStatus;
	}

	public void setAdvertStatus(Integer advertStatus) {
		this.advertStatus = advertStatus;
	}

	public String getAdvertStatusShow() {
		return advertStatusShow;
	}

	public void setAdvertStatusShow(String advertStatusShow) {
		this.advertStatusShow = advertStatusShow;
	}
}
